"use strict";

exports.__esModule = true;
exports.default = createComponent;

function mergeMixinsHook(hookName, options, hooks) {
  if (hooks === void 0) {
    hooks = [];
  }

  if (options.mixins) {
    options.mixins.forEach(function (item) {
      return mergeMixinsHook(hookName, item, hooks);
    });
  }

  options[hookName] && hooks.push(options[hookName]);
  return hooks;
}

function callHookReady(vm) {
  vm.$maproot.ready(function () {
    var opt = vm.constructor.options;
    var hooks = opt.ready;

    for (var i = 0, len = hooks.length; i < len; i++) {
      hooks[i] && hooks[i].call(vm);
    }

    vm.$emit('hook:ready');
  });
}

var register = {
  inject: ['$maproot'],
  beforeCreate: function beforeCreate() {
    var _this = this;

    if (!this.constructor["__isInjectReadyHook"]) {
      var constr = this.constructor;
      var extOpt = constr.extendOptions;
      var hooks = mergeMixinsHook('ready', extOpt);
      constr.options['ready'] = hooks;
      this.constructor["__isInjectReadyHook"] = !0;
    }

    this.$once('hook:mounted', function () {
      return callHookReady(_this);
    });
  },
  computed: {
    __mapComponent: function __mapComponent() {
      return !0;
    }
  }
};

function createComponent(options) {
  if (options === void 0) {
    options = {};
  }

  var _options = options,
      _options$mixins = _options.mixins,
      mixins = _options$mixins === void 0 ? [] : _options$mixins;
  options.mixins = [register].concat(mixins);

  options.install = function (Vue) {
    Vue.component(options.name, options);
  };

  return options;
}